@@ -1,5 +1,4 @@
-#!G:\a-程序代码\网站\app\fastapi-project-basis\venv\Scripts\python.exe
-# -*- coding: utf8 -*-
+#!E:\fastapi-builder-test\fastapi-builder\venv\Scripts\python.exe
 # :Copyright: © 2015 Günter Milde.
 # :License: Released under the terms of the `2-Clause BSD license`_, in short:
 #
@@ -10,8 +9,8 @@
 #
 # .. _2-Clause BSD license: https://opensource.org/licenses/BSD-2-Clause
 #
-# Revision: $Revision: 8567 $
-# Date: $Date: 2020-09-30 13:57:21 +0200 (Mi, 30. Sep 2020) $
+# Revision: $Revision: 9021 $
+# Date: $Date: 2022-03-04 16:54:22 +0100 (Fr, 04. Mär 2022) $
 
 """
 A minimal front end to the Docutils Publisher, producing HTML 5 documents.
@@ -20,15 +19,15 @@ The output is also valid XML.
 """
 
 try:
-    import locale # module missing in Jython
+    import locale  # module missing in Jython
     locale.setlocale(locale.LC_ALL, '')
 except locale.Error:
     pass
 
 from docutils.core import publish_cmdline, default_description
 
-description = (u'Generates HTML5 documents from standalone '
-               u'reStructuredText sources.\n'
+description = ('Generates HTML5 documents from standalone '
+               'reStructuredText sources.\n'
                + default_description)
 
 publish_cmdline(writer_name='html5', description=description)
