@@ -1,4 +1,4 @@
-#!G:\a-程序代码\网站\app\fastapi-project-basis\venv\Scripts\python.exe
+#!E:\fastapi-builder-test\fastapi-builder\venv\Scripts\python.exe
 
 # Author:
 # Contact: grubert@users.sf.net
@@ -21,6 +21,7 @@ except:
 from docutils.core import publish_cmdline, default_description
 from docutils.writers import manpage
 
-description = ("Generates plain unix manual documents.  " + default_description)
+description = ("Generates plain unix manual documents.  "
+               + default_description)
 
 publish_cmdline(writer=manpage.Writer(), description=description)
